@@ -4,6 +4,7 @@ import logging
 import os.path
 import sys
 import traceback
+from contextlib import nullcontext
 from datetime import datetime
 
 import click
@@ -17,7 +18,6 @@ from ._config import make_reader_config
 from ._config import make_reader_from_config
 from ._plugins import LoaderError
 from ._sqlite_utils import DebugConnection
-from ._utils import nullcontext
 
 
 APP_NAME = reader.__name__
@@ -266,7 +266,7 @@ def get_update_status(value):
         return None
     if isinstance(value, Exception):
         return False
-    if not (value.new or value.updated):
+    if not (value.new or value.modified):
         return None
     return True
 
@@ -285,7 +285,7 @@ def iter_update_status(it, length):
         elif not update_status:
             status = red(value)
         else:
-            status = green(f"{value.new} new, {value.updated} updated")
+            status = green(f"{value.new} new, {value.modified} modified")
 
         click.echo(f"{elapsed}\t{pos}\t{url}\t{status}")
 
@@ -332,7 +332,7 @@ def update(reader, url, new_only, workers, verbose):
 
         it = make_it()
     else:
-        it = reader.update_feeds_iter(new_only=new_only, workers=workers)
+        it = reader.update_feeds_iter(new=True if new_only else None, workers=workers)
 
     ok_count = 0
     not_modified_count = 0
@@ -387,10 +387,10 @@ def update(reader, url, new_only, workers, verbose):
                 else:
                     ok_count += 1
                     new_count += value.new
-                    updated_count += value.updated
+                    updated_count += value.modified
     finally:
         click.echo(
-            f"{feed_stats(9999)}; entries: {new_count} new, {updated_count} updated"
+            f"{feed_stats(9999)}; entries: {new_count} new, {updated_count} modified"
         )
 
 
