@@ -1,7 +1,9 @@
 from dataclasses import dataclass
 from datetime import datetime
+from types import MappingProxyType
 from typing import Generic
 from typing import Iterable
+from typing import Mapping
 from typing import NamedTuple
 from typing import Optional
 from typing import Sequence
@@ -10,6 +12,8 @@ from typing import Type
 from typing import TypeVar
 from typing import Union
 
+from ._hash_utils import get_hash
+from ._vendor.functools import cached_property
 from .types import _entry_argument
 from .types import _feed_argument
 from .types import _namedtuple_compat
@@ -22,7 +26,6 @@ from .types import Feed
 from .types import FeedInput
 from .types import TagFilterInput
 
-
 # Private API
 # https://github.com/lemon24/reader/issues/111
 
@@ -48,6 +51,7 @@ class FeedData(_namedtuple_compat):
     def as_feed(self, **kwargs: object) -> Feed:
         """For testing."""
         attrs = dict(self.__dict__)
+        attrs.pop('hash', None)
         attrs.update(kwargs)
         return Feed(**attrs)
 
@@ -55,6 +59,12 @@ class FeedData(_namedtuple_compat):
     def object_id(self) -> str:
         return self.url
 
+    _hash_exclude_ = frozenset({'url', 'updated'})
+
+    @cached_property
+    def hash(self) -> bytes:
+        return get_hash(self)
+
 
 _UpdatedType = TypeVar('_UpdatedType', datetime, Optional[datetime])
 
@@ -109,6 +119,7 @@ class EntryData(Generic[_UpdatedType], _namedtuple_compat):
         """For testing."""
         attrs = dict(self.__dict__)
         feed_url = attrs.pop('feed_url')
+        attrs.pop('hash', None)
         attrs.update(kwargs)
         attrs.setdefault('original_feed_url', feed_url)
         return Entry(**attrs)
@@ -117,6 +128,12 @@ class EntryData(Generic[_UpdatedType], _namedtuple_compat):
     def object_id(self) -> Tuple[str, str]:
         return self.feed_url, self.id
 
+    _hash_exclude_ = frozenset({'feed_url', 'id', 'updated'})
+
+    @cached_property
+    def hash(self) -> bytes:
+        return get_hash(self)
+
 
 class ParsedFeed(NamedTuple):
 
@@ -146,9 +163,12 @@ class FeedForUpdate(NamedTuple):
     #: The date the feed was last updated, according to reader; none if never.
     last_updated: Optional[datetime]
 
-    # Whether the feed had an exception at the last update.
+    #: Whether the feed had an exception at the last update.
     last_exception: bool
 
+    #: The hash of the corresponding FeedData.
+    hash: Optional[bytes]
+
 
 class EntryForUpdate(NamedTuple):
 
@@ -157,6 +177,13 @@ class EntryForUpdate(NamedTuple):
     #: The date the entry was last updated, according to the entry.
     updated: datetime
 
+    #: The hash of the corresponding EntryData.
+    hash: Optional[bytes]
+
+    #: The number of updates due to a different ``hash``
+    #: since the last time ``updated`` changed.
+    hash_changed: Optional[int]
+
 
 class FeedUpdateIntent(NamedTuple):
 
@@ -196,6 +223,9 @@ class EntryUpdateIntent(NamedTuple):
     #: The index of the entry in the feed (zero-based).
     feed_order: int
 
+    #: Same as EntryForUpdate.hash_changed.
+    hash_changed: Optional[int]
+
     @property
     def new(self) -> bool:
         """Whether the entry is new or not."""
@@ -327,3 +357,36 @@ class FeedFilterOptions(NamedTuple):
             raise ValueError("updates_enabled should be one of (None, False, True)")
 
         return cls(feed_url, tag_filter, broken, updates_enabled)
+
+
+@dataclass(frozen=True)
+class NameScheme(_namedtuple_compat):
+    reader_prefix: str
+    plugin_prefix: str
+    separator: str
+
+    @classmethod
+    def from_value(cls, value: Mapping[str, str]) -> 'NameScheme':
+        # Use is validation.
+        self = cls(**value)
+        self.make_reader_name('key')
+        self.make_plugin_name('name', 'key')
+        return self
+
+    def make_reader_name(self, key: str) -> str:
+        return self.reader_prefix + key
+
+    def make_plugin_name(self, plugin_name: str, key: Optional[str] = None) -> str:
+        rv = self.plugin_prefix + plugin_name
+        if key is not None:
+            rv += self.separator + key
+        return rv
+
+
+DEFAULT_RESERVED_NAME_SCHEME = MappingProxyType(
+    {
+        'reader_prefix': '.reader.',
+        'plugin_prefix': '.plugin.',
+        'separator': '.',
+    }
+)
