@@ -3,6 +3,7 @@ import itertools
 import logging
 import numbers
 import warnings
+from contextlib import nullcontext
 from datetime import datetime
 from types import MappingProxyType
 from typing import Any
@@ -11,6 +12,7 @@ from typing import Collection
 from typing import Iterable
 from typing import Iterator
 from typing import Mapping
+from typing import MutableSequence
 from typing import Optional
 from typing import overload
 from typing import Tuple
@@ -35,7 +37,6 @@ from ._types import NameScheme
 from ._types import ParsedFeed
 from ._utils import deprecated_wrapper
 from ._utils import make_pool_map
-from ._utils import nullcontext
 from ._utils import zero_or_one
 from .exceptions import EntryNotFoundError
 from .exceptions import FeedMetadataNotFoundError
@@ -52,6 +53,7 @@ from .types import EntryInput
 from .types import EntrySearchCounts
 from .types import EntrySearchResult
 from .types import EntrySortOrder
+from .types import EntryUpdateStatus
 from .types import Feed
 from .types import FeedCounts
 from .types import FeedInput
@@ -72,8 +74,10 @@ _T = TypeVar('_T')
 _U = TypeVar('_U')
 
 ReaderPluginType = Callable[['Reader'], None]
+AfterEntryUpdateHook = Callable[
+    ['Reader', EntryData[datetime], EntryUpdateStatus], None
+]
 _PostFeedUpdatePluginType = Callable[['Reader', str], None]
-_PostEntryAddPluginType = Callable[['Reader', EntryData[datetime]], None]
 
 
 def make_reader(
@@ -265,6 +269,7 @@ class Reader:
     .. versionadded:: 1.13
         JSON Feed support.
 
+
     """
 
     def __init__(
@@ -286,7 +291,29 @@ class Reader:
 
         self._updater = reader._updater
         self._post_feed_update_plugins: Collection[_PostFeedUpdatePluginType] = []
-        self._post_entry_add_plugins: Collection[_PostEntryAddPluginType] = []
+
+        #: List of functions called for each updated entry
+        #: after the feed was updated.
+        #:
+        #: Each function is called with:
+        #:
+        #: * `reader` – the :class:`Reader` instance
+        #: * `entry` – an :class:`Entry`-like object
+        #: * `status` – an :class:`EntryUpdateStatus` value
+        #:
+        #: Each function should return :const:`None`.
+        #:
+        #: .. warning::
+        #:
+        #:  The only `entry` attributes guaranteed to be present are
+        #:  :attr:`~Entry.feed_url`, :attr:`~Entry.id`,
+        #:  and :attr:`~Entry.object_id`;
+        #:  all other attributes may be missing
+        #:  (accessing them may raise :exc:`AttributeError`).
+        #:
+        #: .. versionadded:: 1.20
+        #:
+        self.after_entry_update_hooks: MutableSequence[AfterEntryUpdateHook] = []
 
         if _called_directly:
             warnings.warn(
@@ -606,7 +633,13 @@ class Reader:
         url = _feed_argument(feed)
         self._storage.set_feed_updates_enabled(url, False)
 
-    def update_feeds(self, new_only: bool = False, workers: int = 1) -> None:
+    def update_feeds(
+        self,
+        new_only: Union[bool, MissingType] = MISSING,
+        workers: int = 1,
+        *,
+        new: Union[Optional[bool], MissingType] = MISSING,
+    ) -> None:
         """Update all the feeds that have updates enabled.
 
         Silently skip feeds that raise :exc:`ParseError`.
@@ -614,8 +647,17 @@ class Reader:
         Roughly equivalent to ``for _ in reader.update_feed_iter(...): pass``.
 
         Args:
-            new_only (bool): Only update feeds that have never been updated.
+            new_only (bool):
+                Only update feeds that have never been updated.
+                Defaults to False.
+
+                .. deprecated:: 1.19
+                    Use ``new`` instead.
+
             workers (int): Number of threads to use when getting the feeds.
+            new (bool or None):
+                Only update feeds that have never been updated
+                / have been updated before. Defaults to None.
 
         Raises:
             StorageError
@@ -635,8 +677,13 @@ class Reader:
             Previously, entries would be updated only if the
             entry :attr:`~Entry.updated` was *newer* than the stored one.
 
+        .. deprecated:: 1.19
+            The ``new_only`` argument
+            (will be removed in *reader* 2.0);
+            use ``new`` instead.
+
         """
-        for url, value in self.update_feeds_iter(new_only, workers):
+        for url, value in self.update_feeds_iter(new_only, workers, new=new):
             if isinstance(value, ParseError):
                 log.exception(
                     "update feed %r: error while getting/parsing feed, "
@@ -650,13 +697,26 @@ class Reader:
             assert not isinstance(value, Exception), value
 
     def update_feeds_iter(
-        self, new_only: bool = False, workers: int = 1
+        self,
+        new_only: Union[bool, MissingType] = MISSING,
+        workers: int = 1,
+        *,
+        new: Union[Optional[bool], MissingType] = MISSING,
     ) -> Iterable[UpdateResult]:
         """Update all the feeds that have updates enabled.
 
         Args:
-            new_only (bool): Only update feeds that have never been updated.
+            new_only (bool):
+                Only update feeds that have never been updated.
+                Defaults to False.
+
+                .. deprecated:: 1.19
+                    Use ``new`` instead.
+
             workers (int): Number of threads to use when getting the feeds.
+            new (bool or None):
+                Only update feeds that have never been updated
+                / have been updated before. Defaults to None.
 
         Yields:
             :class:`UpdateResult`:
@@ -680,14 +740,34 @@ class Reader:
             Update entries whenever their content changes.
             See :meth:`~Reader.update_feeds` for details.
 
+        .. deprecated:: 1.19
+            The ``new_only`` argument
+            (will be removed in *reader* 2.0);
+            use ``new`` instead.
+
         """
         if workers < 1:
             raise ValueError("workers must be a positive integer")
 
+        if new is MISSING and new_only is MISSING:
+            new_final = None
+        elif new is MISSING and new_only is not MISSING:
+            new_final = True if new_only else None
+            warnings.warn(
+                "new_only is deprecated and will be removed in reader 2.0. "
+                "Use new instead.",
+                DeprecationWarning,
+            )
+        elif new is not MISSING and new_only is MISSING:
+            assert not isinstance(new, MissingType)  # mypy pleasing
+            new_final = new
+        else:
+            raise TypeError("new and new_only are mutually exclusive")
+
         make_map = nullcontext(builtins.map) if workers == 1 else make_pool_map(workers)
 
         with make_map as map:
-            results = self._update_feeds(new_only=new_only, map=map)
+            results = self._update_feeds(new=new_final, map=map)
 
             for url, value in results:
                 if isinstance(value, FeedNotFoundError):
@@ -752,7 +832,7 @@ class Reader:
     def _update_feeds(
         self,
         url: Optional[str] = None,
-        new_only: bool = False,
+        new: Optional[bool] = None,
         enabled_only: bool = True,
         map: Callable[[Callable[[Any], Any], Iterable[Any]], Iterator[Any]] = map,
     ) -> Iterator[Tuple[str, Union[UpdatedFeed, None, Exception]]]:
@@ -785,9 +865,7 @@ class Reader:
         # It may make sense to also have _get_entries_for_update run in
         # parallel with a different (slower) storage, but for now we're good.
 
-        feeds_for_update = self._storage.get_feeds_for_update(
-            url, new_only, enabled_only
-        )
+        feeds_for_update = self._storage.get_feeds_for_update(url, new, enabled_only)
         feeds_for_update = builtins.map(
             self._updater.process_old_feed, feeds_for_update
         )
@@ -868,12 +946,12 @@ class Reader:
         for entry in entries_to_update:
             if entry.new:
                 new_count += 1
+                entry_status = EntryUpdateStatus.NEW
             else:
                 updated_count += 1
-            if not entry.new:
-                continue
-            for entry_plugin in self._post_entry_add_plugins:
-                entry_plugin(self, entry.entry)
+                entry_status = EntryUpdateStatus.MODIFIED
+            for entry_hook in self.after_entry_update_hooks:
+                entry_hook(self, entry.entry, entry_status)
 
         return new_count, updated_count
 
@@ -1175,7 +1253,7 @@ class Reader:
                     f"get_feed_metadata() takes 1 positional arguments, but {len(args) + 1} were given"
                 )
             warnings.warn(
-                "the get_feed_metadata(feed, key[, default]) -> value "
+                "The get_feed_metadata(feed, key[, default]) -> value "
                 "version of get_feed_metadata() is deprecated "
                 "and will be removed in reader 2.0. "
                 "Use get_feed_metadata_item() instead.",
