@@ -1,6 +1,8 @@
+import warnings
+from typing import Any
 from typing import Tuple
 
-from ._vendor.cached_property import cached_property
+from ._vendor.functools import cached_property
 
 
 class _FancyExceptionBase(Exception):
@@ -99,22 +101,24 @@ class ParseError(FeedError):
 
 
 class EntryError(ReaderError):
-    """An entry error occured."""
+    """An entry error occurred.
 
-    def __init__(self, url: str, id: str, message: str = '') -> None:
+    .. versionchanged:: 1.18
+        The ``url`` argument/attribute was renamed to ``feed_url``.
+    """
+
+    def __init__(self, feed_url: str, id: str, message: str = '') -> None:
         super().__init__(message)
 
-        # TODO: .url should be .feed_url
-
         #: The feed URL.
-        self.url = url
+        self.feed_url = feed_url
 
         #: The entry id.
         self.id = id
 
     @property
     def _str(self) -> str:
-        return repr((self.url, self.id))
+        return repr((self.feed_url, self.id))
 
     @property
     def object_id(self) -> Tuple[str, str]:
@@ -123,7 +127,22 @@ class EntryError(ReaderError):
         .. versionadded:: 1.12
 
         """
-        return self.url, self.id
+        return self.feed_url, self.id
+
+    @property
+    def url(self) -> str:
+        """Deprecated alias for :attr:`EntryError.feed_url`.
+
+        .. deprecated: 1.18
+
+        """
+        warnings.warn(
+            "EntryError.url is deprecated "
+            "and will be removed in reader 2.0. "
+            "Use EntryError.feed_url instead.",
+            DeprecationWarning,
+        )
+        return self.feed_url
 
 
 class EntryNotFoundError(EntryError):
@@ -133,28 +152,61 @@ class EntryNotFoundError(EntryError):
 
 
 class MetadataError(ReaderError):
-    """A feed metadata error occured."""
+    """A metadata error occurred.
 
-    def __init__(self, url: str, key: str, message: str = '') -> None:
-        super().__init__(message)
+    .. versionchanged:: 1.18
 
-        #: The feed URL.
-        self.url = url
+        Signature changed from ``MetadataError(message='')``
+        to ``MetadataError(key, message='')``.
+
+    """
+
+    def __init__(self, *args: Any, key: str, **kwargs: Any) -> None:
+        super().__init__(*args, **kwargs)
 
         #: The metadata key.
         self.key = key
 
     @property
     def _str(self) -> str:
-        return f"{self.url!r}: {self.key!r}"
+        return f"{super()._str}: {self.key!r}"
 
 
 class MetadataNotFoundError(MetadataError):
-    """Feed metadata not found."""
+    """Metadata not found.
+
+    .. versionchanged:: 1.18
+
+        Signature changed from ``MetadataNotFoundError(url, key, message='')``
+        to ``MetadataNotFoundError(key, message='')``.
+
+    """
 
     message = "no such metadata"
 
 
+class FeedMetadataNotFoundError(MetadataNotFoundError, FeedError):
+    """Feed metadata not found.
+
+    .. versionadded:: 1.18
+
+    """
+
+    def __init__(self, url: str, key: str, message: str = '') -> None:
+        super().__init__(url, key=key, message=message)
+
+
+class EntryMetadataNotFoundError(MetadataNotFoundError, EntryError):
+    """Entry metadata not found.
+
+    .. versionadded:: 1.18
+
+    """
+
+    def __init__(self, feed_url: str, id: str, key: str, message: str = '') -> None:
+        super().__init__(feed_url, id, key=key, message=message)
+
+
 class StorageError(ReaderError):
     """An exception was raised by the underlying storage.
 
@@ -178,13 +230,13 @@ class SearchNotEnabledError(SearchError):
     message = "operation not supported with search disabled"
 
 
-class InvalidSearchQueryError(SearchError):
+class InvalidSearchQueryError(SearchError, ValueError):
     """The search query provided was somehow invalid."""
 
 
-class _NotModified(FeedError):
-    """Feed not modified.
+class PluginError(ReaderError):
+    """A plugin-related exception."""
 
-    Signaling exception used internally by Parser.
 
-    """
+class InvalidPluginError(PluginError, ValueError):
+    """An invalid plugin was provided."""
