@@ -1,6 +1,8 @@
 import dataclasses
+import enum
 import re
 import traceback
+import warnings
 from dataclasses import dataclass
 from datetime import datetime
 from types import MappingProxyType
@@ -479,10 +481,39 @@ class EntrySearchResult(_namedtuple_compat):
         return self.feed_url, self.id
 
 
+class EntryUpdateStatus(enum.Enum):
+
+    """Enum representing how an entry was updated.
+
+    .. versionadded:: 1.20
+
+    """
+
+    #: The entry did not previously exist in storage.
+    NEW = 'new'
+
+    #: The entry existed in storage,
+    #: but had different data from the one in the feed file.
+    MODIFIED = 'modified'
+
+
 # Semi-public API (typing support)
 
 
 # TODO: Could we use some kind of str-compatible enum here?
+#
+# Yes:
+#
+# class Order(enum.Enum):
+#    TITLE = 'title'
+#    ADDED = 'added'
+#
+# The public methods should then take Union[str, Order],
+# and use the value _only_ as Order(arg) for validation.
+# Having the arguments typed as Literals is silly anyway,
+# because we sometimes get them dynamically, e.g.
+# https://github.com/lemon24/reader/blob/1.18/src/reader/_app/__init__.py#L151
+#
 FeedSortOrder = Literal['title', 'added']
 EntrySortOrder = Literal['recent', 'random']
 SearchSortOrder = Literal['relevant', 'recent', 'random']
@@ -633,16 +664,37 @@ class UpdatedFeed:
 
     .. versionadded:: 1.14
 
+    .. versionchanged:: 1.19
+        The ``updated`` argument/attribute was renamed to ``modified``.
+
     """
 
     #: The URL of the feed.
     url: str
 
-    #: The number of new entries.
+    #: The number of new entries
+    #: (entries that did not previously exist in storage).
     new: int
 
-    #: The number of updated entries.
-    updated: int
+    #: The number of modified entries
+    #: (entries that existed in storage,
+    #: but had different data than the corresponding feed file entry.)
+    modified: int
+
+    @property
+    def updated(self) -> int:
+        """Deprecated alias for :attr:`UpdatedFeed.modified`.
+
+        .. deprecated: 1.19
+
+        """
+        warnings.warn(
+            "UpdatedFeed.updated is deprecated "
+            "and will be removed in reader 2.0. "
+            "Use UpdatedFeed.modified instead.",
+            DeprecationWarning,
+        )
+        return self.modified
 
 
 class UpdateResult(NamedTuple):
