@@ -6,7 +6,6 @@ import requests
 import wsgiadapter
 from fakeparser import Parser
 
-from reader import make_reader
 from reader._app import create_app
 from reader._config import make_reader_config
 from reader._config import make_reader_from_config
@@ -30,7 +29,7 @@ def browser(db_path):
 
 
 @pytest.mark.slow
-def test_mark_as_read_unread(db_path, browser):
+def test_mark_as_read_unread(db_path, make_reader, browser):
     parser = Parser()
     feed = parser.feed(1, datetime(2010, 1, 1))
     entry = parser.entry(1, 1, datetime(2010, 1, 1))
@@ -64,7 +63,7 @@ def test_mark_as_read_unread(db_path, browser):
 
 
 @pytest.mark.slow
-def test_mark_all_as_read_unread(db_path, browser):
+def test_mark_all_as_read_unread(db_path, make_reader, browser):
     parser = Parser()
     feed = parser.feed(1, datetime(2010, 1, 1))
     entry = parser.entry(1, 1, datetime(2010, 1, 1))
@@ -104,7 +103,7 @@ def test_mark_all_as_read_unread(db_path, browser):
 
 
 @pytest.mark.slow
-def test_add_delete_feed(db_path, browser, monkeypatch):
+def test_add_delete_feed(db_path, make_reader, browser, monkeypatch):
     parser = Parser()
     feed = parser.feed(1, datetime(2010, 1, 1))
     entry = parser.entry(1, 1, datetime(2010, 1, 1))
@@ -171,7 +170,7 @@ def test_add_delete_feed(db_path, browser, monkeypatch):
 
 
 @pytest.mark.slow
-def test_delete_feed_from_entries_page_redirects(db_path, browser):
+def test_delete_feed_from_entries_page_redirects(db_path, make_reader, browser):
     parser = Parser()
     feed = parser.feed(1, datetime(2010, 1, 1))
     entry = parser.entry(1, 1, datetime(2010, 1, 1))
@@ -192,7 +191,7 @@ def test_delete_feed_from_entries_page_redirects(db_path, browser):
 
 
 @pytest.mark.slow
-def test_limit(db_path, browser):
+def test_limit(db_path, make_reader, browser):
     parser = Parser()
     feed = parser.feed(1, datetime(2010, 1, 1))
     one = parser.entry(1, 1, datetime(2010, 1, 1))
@@ -217,7 +216,7 @@ def test_limit(db_path, browser):
 
 
 @pytest.mark.slow
-def test_search(db_path, browser):
+def test_search(db_path, make_reader, browser):
     parser = Parser()
     feed = parser.feed(1, datetime(2010, 1, 1))
     one = parser.entry(1, 1, datetime(2010, 1, 1), title='one')
