@@ -383,26 +383,35 @@ def test_update_not_modified(reader, call_update_method):
     assert set(reader.get_entries()) == set()
 
 
-def test_update_new_only(reader):
+def test_update_new(reader):
     parser = Parser()
     reader._parser = parser
 
     one = parser.feed(1, datetime(2010, 1, 1))
     reader._now = lambda: datetime(2010, 1, 1)
     reader.add_feed(one.url)
-    reader.update_feeds(new_only=True)
+    reader.update_feeds(new=True)
 
     assert len(set(reader.get_feeds())) == 1
     assert set(reader.get_entries()) == set()
 
-    entry_one = parser.entry(1, 1, datetime(2010, 1, 1))
+    one = parser.feed(1, datetime(2010, 2, 1), title='title')
     two = parser.feed(2, datetime(2010, 2, 1))
     entry_two = parser.entry(2, 2, datetime(2010, 2, 1))
-    reader._now = lambda: datetime(2010, 1, 2)
+    reader._now = lambda: datetime(2010, 1, 1, 12)
     reader.add_feed(two.url)
-    reader.update_feeds(new_only=True)
 
-    two = two.as_feed(added=datetime(2010, 1, 2), last_updated=datetime(2010, 1, 2))
+    reader.update_feeds(new=False)
+    assert {(f.url, f.last_updated, f.title) for f in reader.get_feeds()} == {
+        ('1', datetime(2010, 1, 1, 12), 'title'),
+        ('2', None, None),
+    }
+
+    reader._now = lambda: datetime(2010, 1, 2)
+    entry_one = parser.entry(1, 1, datetime(2010, 1, 1))
+    reader.update_feeds(new=True)
+
+    two = two.as_feed(added=datetime(2010, 1, 1, 12), last_updated=datetime(2010, 1, 2))
     assert len(set(reader.get_feeds())) == 2
     assert set(reader.get_entries()) == {
         entry_two.as_entry(feed=two, last_updated=datetime(2010, 1, 2))
@@ -419,7 +428,7 @@ def test_update_new_only(reader):
     }
 
 
-def test_update_new_only_no_last_updated(reader):
+def test_update_new_no_last_updated(reader):
     """A feed should be updated if it has no last_updated.
 
     https://github.com/lemon24/reader/issues/95
@@ -436,16 +445,16 @@ def test_update_new_only_no_last_updated(reader):
         FeedUpdateIntent(feed.url, None, feed=feed._replace(updated=None))
     )
 
-    reader.update_feeds(new_only=True)
+    reader.update_feeds(new=True)
 
     parser.entry(1, 1, datetime(2010, 1, 1))
-    reader.update_feeds(new_only=True)
+    reader.update_feeds(new=True)
 
     # the entry isn't added because feed is not new on the second update_feeds
     assert len(list(reader.get_entries(feed=feed.url))) == 0
 
 
-def test_update_new_only_not_modified(reader):
+def test_update_new_not_modified(reader):
     """A feed should not be considered new anymore after getting _NotModified.
 
     https://github.com/lemon24/reader/issues/95
@@ -459,13 +468,13 @@ def test_update_new_only_not_modified(reader):
     reader.add_feed(feed.url)
     reader._storage.update_feed(FeedUpdateIntent(feed.url, None, feed=feed))
 
-    reader.update_feeds(new_only=True)
+    reader.update_feeds(new=True)
 
     parser = Parser.from_parser(parser)
     reader._parser = parser
 
     parser.entry(1, 1, datetime(2010, 1, 1))
-    reader.update_feeds(new_only=True)
+    reader.update_feeds(new=True)
 
     # the entry isn't added because feed is not new on the second update_feeds
     assert len(list(reader.get_entries(feed=feed.url))) == 0
@@ -610,7 +619,7 @@ def test_last_exception_failed(reader, call_update_method):
     reader._parser = old_parser
     old_parser.feed(2, datetime(2010, 1, 1))
     reader.add_feed('2')
-    reader.update_feeds(new_only=True)
+    reader.update_feeds(new=True)
     assert reader.get_feed('1').last_exception == last_exception
     assert reader.get_feed('2').last_exception is None
 
@@ -752,7 +761,13 @@ def test_update_feed_deleted(
             reader.delete_feed(feed.url)
         finally:
             blocking_parser.can_return_from_parser.set()
-            reader.close()
+            try:
+                reader.close()
+            except StorageError as e:
+                if 'database is locked' in str(e):
+                    pass  # sometimes, it can be; we don't care
+                else:
+                    raise
 
     t = threading.Thread(target=target)
     t.start()
@@ -851,12 +866,12 @@ def test_update_feeds_iter(reader, call_update_iter_method):
         reader.add_feed(feed)
 
     assert dict(call_update_iter_method(reader)) == {
-        '1': UpdatedFeed(url='1', new=2, updated=0),
-        '2': UpdatedFeed(url='2', new=1, updated=0),
+        '1': UpdatedFeed(url='1', new=2, modified=0),
+        '2': UpdatedFeed(url='2', new=1, modified=0),
     }
 
     assert next(call_update_iter_method(reader)) == UpdateResult(
-        '1', UpdatedFeed(url='1', new=0, updated=0)
+        '1', UpdatedFeed(url='1', new=0, modified=0)
     )
 
     one_two = parser.entry(1, 2, datetime(2010, 2, 2), title='new title')
@@ -869,8 +884,8 @@ def test_update_feeds_iter(reader, call_update_iter_method):
     rv = dict(call_update_iter_method(reader))
     assert set(rv) == set('123')
 
-    assert rv['1'] == UpdatedFeed(url='1', new=2, updated=1)
-    assert rv['2'] == UpdatedFeed(url='2', new=0, updated=0)
+    assert rv['1'] == UpdatedFeed(url='1', new=2, modified=1)
+    assert rv['2'] == UpdatedFeed(url='2', new=0, modified=0)
 
     assert isinstance(rv['3'], ParseError)
     assert rv['3'].url == '3'
@@ -909,7 +924,7 @@ def test_update_feeds_iter_raised_exception(reader, exc_type, call_update_iter_m
     if not sys.implementation.name == 'pypy':
         # for some reason, on PyPy the updates sometimes
         # happen out of order and rv is empty
-        assert rv == {'1': UpdatedFeed(url='1', new=0, updated=0)}
+        assert rv == {'1': UpdatedFeed(url='1', new=0, modified=0)}
 
 
 def test_mark_as_read_unread(reader, entry_arg):
