@@ -8,9 +8,8 @@ from reader._sql_utils import Query
 
 
 def test_query_simple():
-    assert str(
-        BaseQuery().SELECT('select').FROM('from').JOIN('join').WHERE('where')
-    ) == dedent(
+    query = BaseQuery().SELECT('select').FROM('from').JOIN('join').WHERE('where')
+    assert str(query) == dedent(
         """\
         SELECT
             select
@@ -35,7 +34,7 @@ def test_query_complicated():
     * no-argument keywords have no effect
 
     """
-    assert str(
+    query = (
         BaseQuery()
         .WHERE()
         .OUTER_JOIN('outer join')
@@ -53,6 +52,7 @@ def test_query_complicated():
         .WHERE('where')
         .ORDER_BY('third')
         .OUTER_JOIN('another outer join')
+        # this isn't technically valid
         .WITH('first cte')
         .GROUP_BY('another group by')
         .HAVING('another having')
@@ -62,10 +62,13 @@ def test_query_complicated():
         .NATURAL_JOIN('natural join')
         .SELECT()
         .SELECT()
-    ) == dedent(
+    )
+    assert str(query) == dedent(
         """\
         WITH
-            first cte,
+            (
+                first cte
+            ),
             fancy AS (
                 second cte
             )
@@ -79,10 +82,10 @@ def test_query_complicated():
             another from
         OUTER JOIN
             outer join
-        OUTER JOIN
-            another outer join
         JOIN
             join
+        OUTER JOIN
+            another outer join
         JOIN
             another join
         NATURAL JOIN
@@ -106,6 +109,19 @@ def test_query_complicated():
     )
 
 
+def test_query_flag():
+    query = BaseQuery().SELECT('one').SELECT('two').SELECT_DISTINCT()
+    assert str(query) == dedent(
+        """\
+        SELECT DISTINCT
+            one,
+            two
+        """
+    )
+    with pytest.raises(ValueError):
+        BaseQuery().SELECT_MAGIC('one')
+
+
 def test_query_deepcopy():
     deepcopy(Query())
 
@@ -134,7 +150,7 @@ def test_scrolling_window():
     query = make_query()
     query.scrolling_window_order_by('one')
     query.LIMIT('limit')
-    query.add_last()
+    query.add_last([])
     assert str(query) == str(
         make_query(BaseQuery)
         .WHERE(
@@ -153,7 +169,7 @@ def test_scrolling_window():
     query = make_query()
     query.scrolling_window_order_by('one', desc=True, keyword='HAVING')
     query.LIMIT('limit')
-    query.add_last()
+    query.add_last([])
     assert str(query) == str(
         make_query(BaseQuery)
         .HAVING(
@@ -174,9 +190,9 @@ def test_scrolling_window_last():
     query = Query().SELECT()
     query.scrolling_window_order_by()
     assert query.extract_last([1, 2, 3]) == None
-    assert dict(query.last_params(None)) == {}
+    assert dict(query.add_last(None)) == {}
 
-    query = Query().SELECT('one', 'two', 'three')
+    query = Query().SELECT('one', 'two', ('three', 'max(3)'))
     query.scrolling_window_order_by('one', 'three')
     assert query.extract_last([1, 2, 3]) == (1, 3)
-    assert dict(query.last_params([1, 3])) == {'last_0': 1, 'last_1': 3}
+    assert dict(query.add_last([1, 3])) == {'last_0': 1, 'last_1': 3}
